class SystemSettingsController < ApplicationController
  protect_with("SystemSetting", "System Settings", RxModule::Authorization.crud(false, :show, :update))

  # This endpoint is to provide Rx-Module an access to system settings that by-pass user permissions
  def get_system_settings
    @model = SystemSetting.instance
    render "system_settings/show"
  end

  def show
    @model = SystemSetting.instance
  end

  def customer_logo
    @model = SystemSetting.instance
    if @model.customer_logo_file&.attached?
      response.headers["Content-Type"] = @model.customer_logo_file.content_type
      @model.customer_logo_file.download do |chunk|
        response.stream.write(chunk)
      end
    else
      head :no_content
    end
  end

  def brand_logo
    @model = SystemSetting.instance
    if @model.is_satisloh_customer?
      response.headers["Expires"] = 1.year.from_now.httpdate
      response.headers["Cache-Control"] = "public"
      expires_in 1.year, public: true
      send_file(Rails.root.join("public/brand/satisloh", "mes_logo.png"))
    else
      head :no_content
    end
  end

  def update
    @model = SystemSetting.instance

    # Because the layout can contain image, it is passed in via form data which has to be stringified
    data = JSON.parse(params["settings"], symbolize_names: true)

    unless data.blank?
      @model.assign_attributes({
        time_format: data[:time_format],
        date_format: data[:date_format],
        date_time_separator: data[:date_time_separator],
        lens_tray_orientation: data[:lens_tray_orientation]
      })
    end

    if params["logo"]
      file = params["logo"]
      @model.customer_logo_file.attach(io: file, filename: File.basename(file.path), content_type: file.content_type, identify: false)
    elsif data[:clear_logo] && @model.customer_logo_file.attached?
      @model.customer_logo_file.purge
    end

    if @model.save
      ActionCable.server.broadcast "everything", {
        model: JSON.parse(@model.to_json),
        class: @model.broadcast_class_name,
        action: false,
        timestamp: Time.now.to_i
      }
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end
end
