import * as React from 'react';
import {FunctionComponent} from 'react';
import {Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {ButtonField, useFlag} from "@rx-suite/ui";
import {t, Trans} from "@lingui/macro";

type Props = {
    result?: Record<string, unknown>
}

const FormattedResult: FunctionComponent<Props> = ({result}) => {
    if (!result) return null;

    return JSON.stringify(result, null, 4);
}

export const PingResult: FunctionComponent<Props> = ({result}) => {
    const [open, , close, toggle] = useFlag(false);

    return (
        <>
            <ButtonField text={t`View Last Result`} onClick={toggle} disabled={!result}/>
            <Dialog open={open} maxWidth={'md'}>
                <DialogTitle>
                    <Trans>Last Ping Result</Trans>
                </DialogTitle>
                <DialogContent>
                    <pre>
                        <FormattedResult result={result}/>
                    </pre>
                </DialogContent>
                <DialogActions>
                    <ButtonField text={t`Close`} onClick={close}/>
                </DialogActions>
            </Dialog>
        </>
    )
}