import * as React from 'react';
import {useCallback, useEffect, useState} from 'react';
import {observer} from "mobx-react-lite";
import {RxModuleComponentStore} from "../../stores/RxModuleComponentStore";
import {UserModel} from "../../stores/UserStore";
import {t} from "@lingui/macro";
import {ButtonField} from "@rx-suite/ui";
import Add from "@material-ui/icons/Add";
import {CurrentUserModel} from '@rx-suite/stores';

export const ConnectToRxuniverseButton: React.FunctionComponent<{ user: UserModel | CurrentUserModel }> = observer(({user}) => {
    React.useEffect(() => {
        RxModuleComponentStore.getAll();
    }, []);
    const rxuniverseApiModule = RxModuleComponentStore.models.find(app => app.module_id === "rx_universe_api");

    const redirectUrl = React.useMemo(() => {
        const url = new URL("api/oauth2/rxuniverse", window.location.origin);
        url.searchParams.append('user_id', user.getId());
        return url;
    }, [user]);
    const connectUrl = React.useMemo(() => {
        if (!rxuniverseApiModule?.url) {
            return null;
        }
        const url = new URL("/oauth2/authorize", rxuniverseApiModule.url as string);
        url.searchParams.append('redirect_url', redirectUrl.toString());
        return url;
    }, [rxuniverseApiModule?.url, redirectUrl]);

    const [loginPopup, setLoginPopup] = useState<Window | null>(null);
    const connectClick = useCallback(() => {
        const width = 650;
        const height = 500;
        const target = "_blank";
        const left = window.screenX + ((window.outerWidth - width) / 2);
        const top = window.screenY + ((window.outerHeight - height) / 2.5);
        setLoginPopup(window.open(connectUrl!.toString(), target, `width=${width},height=${height},left=${left},top=${top},popup=true`));
    }, [connectUrl, setLoginPopup]);

    // Borrowed from https://elvisciotti.medium.com/how-to-create-a-oauth-popup-in-react-7ab102ea48f
    useEffect(() => {
            if (!loginPopup) {
                return;
            }

            const cleanup = () => {
                if (timer) {
                    clearInterval(timer);
                }
                if (loginPopup) {
                    loginPopup.close();
                }
                if (user) {
                    user.getOAuths(true);
                }
                setLoginPopup(null);
            };

            const timer = setInterval(() => {
                if (!loginPopup || loginPopup.closed) {
                    cleanup();
                    return;
                }
                let currentUrl = '';
                try {
                    currentUrl = loginPopup.location.href;
                } catch {
                    // this means we fell into a cross-origin problem because we are currently displaying the OAuth login (Uncaught DOMException: Blocked a frame with origin "http://127.0.0.1:3000" from accessing a cross-origin frame.)
                    return;
                }
                if (!currentUrl) {
                    return;
                }
                if (/\/OAuthSuccess/.test(currentUrl)) {
                    loginPopup.close();
                    user.getOAuths(true);
                }
            }, 500);

            return cleanup
        },
        [loginPopup, user, setLoginPopup]
    )

    if (!connectUrl) {
        return null;
    }

    return (
        <ButtonField
            startIcon={<Add/>}
            text={t`Add Rx-Universe Connection`}
            onClick={connectClick}
            loading={!!loginPopup}
        />
    );
});