# == Schema Information
#
# Table name: component_permissions
#
#  id                    :bigint           not null, primary key
#  action_display_name   :string(4000)
#  target_category       :string(4000)
#  target_display_name   :string(4000)
#  created_at            :datetime         not null
#  updated_at            :datetime         not null
#  action_id             :string(4000)
#  component_id          :bigint           not null
#  feature_module_id     :string(4000)
#  feature_subfeature_id :string(4000)
#  target_id             :string(4000)
#
# Indexes
#
#  index_component_permissions_on_component_id  (component_id)
#
# Foreign Keys
#
#  fk_rails_...  (component_id => components.id) ON DELETE => cascade
#
class ComponentPermission < ApplicationRecord
  belongs_to :component
  has_many :role_permissions
  has_many :roles, through: :role_permissions

  def self.module_token_permissions
    eager_load(:component).find_each.map(&:auth_json)
  end

  def auth_json
    json = as_json(
      except: [:id, :created_at, :updated_at],
      include: {
        component: {
          only: :module_id
        }
      }
    )
    json["component"] = json["component"]["module_id"]
    json["permitted"] = true
    json
  end
end
